@@ -14,25 +14,42 @@ pub enum Command {
     /// Generate wit files
     Wit {
         /// Specify output file to generate wit definitions
+        /// 
+        /// Default: './witgen.wit`
         #[clap(long, short = 'o')]
         output: Option<PathBuf>,
 
         /// Arguments to be passed to `cargo rustc ...`.
+        /// Can mostly ignore.
         #[clap(last = true)]
         args: Vec<String>,
 
         /// Specify prefix file to copy into top of the generated wit file
-        #[clap(long, short = 'p')]
+        #[clap(long, name = "path to wit", short = 'p')]
         prefix_file: Option<PathBuf>,
 
         /// Specify prefix string to copy into top of the generated wit file
+        /// 
         /// `--prefix-string 'use * from "string.wit"'`
         #[clap(long, short = 's')]
         prefix_string: Option<String>,
 
-        /// Generate TypeScript file from wit file
-        #[clap(long, short = 't')]
+        /// Generate TypeScript file from generated wit file in one step
+        ///  
+        /// `-t ./dist` --> `./dist/index.ts`
+        /// 
+        /// `-t ./dist/file.ts` --> `./dist/file.ts`
+        #[clap(long, name = "file or directory", short = 't')]
         typescript: Option<PathBuf>,
+
+        /// Include near-sdk's base wit types
+        #[clap(long)]
+        sdk: bool,
+
+        /// Include near-contract-standards's base wit types.
+        /// This includes the sdk's types
+        #[clap(long)]
+        standards: bool,
     },
 
     /// Generate ts file from wit
@@ -45,8 +62,8 @@ pub enum Command {
       /// 
       /// `-o ./dist` --> `./dist/index.ts`
       /// 
-      /// `-o ./dist/file.ts` --> `./dist/file.ts
-      #[clap(long, short = 'o')]
+      /// `-o ./dist/file.ts` --> `./dist/file.`ts
+      #[clap(long, name= "file or directory", short = 'o')]
       output: Option<PathBuf>,
 
     },
